@@ -1,7 +1,11 @@
 package App::Fasops::Command::links;
+use strict;
+use warnings;
+use autodie;
 
 use App::Fasops -command;
-use App::Fasops::Common qw(:all);
+use App::RL::Common;
+use App::Fasops::Common;
 
 use constant abstract => 'scan blocked fasta files and output links between pieces';
 
@@ -55,15 +59,15 @@ sub execute {
             next if substr( $line, 0, 1 ) eq "#";
 
             if ( ( $line eq '' or $line =~ /^\s+$/ ) and $content ne '' ) {
-                my $info_of = parse_block($content);
+                my $info_of = App::Fasops::Common::parse_block($content);
                 $content = '';
 
                 my @names = keys %{$info_of};
 
                 for ( my $i = 0; $i <= $#names; $i++ ) {
                     for ( my $j = $i + 1; $j <= $#names; $j++ ) {
-                        my $header1 = encode_header( $info_of->{ $names[$i] }, 1 );
-                        my $header2 = encode_header( $info_of->{ $names[$j] }, 1 );
+                        my $header1 = App::RL::Common::encode_header( $info_of->{ $names[$i] }, 1 );
+                        my $header2 = App::RL::Common::encode_header( $info_of->{ $names[$j] }, 1 );
                         push @links, [ $header1, $header2 ];
                     }
                 }
